@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$MooseX::FunkyAttributes::Role::Attribute::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::FunkyAttributes::Role::Attribute::VERSION   = '0.002';
+	$MooseX::FunkyAttributes::Role::Attribute::VERSION   = '0.003';
 }
 
 use Moose::Role;
@@ -53,11 +53,13 @@ has custom_init => (
 my @i = qw( set get weaken has clear );
 for my $i (@i)
 {
-	my $custom = "custom_inline_$i";
+	my $non_inline = "custom_$i";
+	my $custom     = "custom_inline_$i";
+	my $has_custom = "has_$custom";
 	has $custom => (
 		is        => 'ro',
 		isa       => 'CodeRef',
-		predicate => "has_$custom",
+		predicate => $has_custom,
 	);
 	
 	my $guts_method =
@@ -67,11 +69,20 @@ for my $i (@i)
 	
 	around $guts_method => sub
 	{
-		my ($orig, $self, @args) = @_;
-		if ($self->has_all_inliners) {
-			return $self->$custom->($self, @args);
-		}
-		return $self->$orig(@args);
+		my $next = shift;
+		my $self = shift;
+		my ($instance_var, $param_var) = @_;
+		
+		return $self->$custom->($self, @_) if $self->$has_custom;
+		
+		return sprintf(
+			'do { my $attr = Moose::Util::find_meta(ref(%s))->get_attribute(%s); local $_ = %s; $attr->%s->($attr'.join('',map(',%s',@_)).') }',
+			$instance_var,
+			B::perlstring($self->name),
+			$instance_var,
+			$non_inline,
+			@_,
+		);
 	};
 }
 
@@ -371,7 +382,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
